==> victory-0.13.7-1.jar: cljsjs/common/victory.ext.js <==
// List manually adapted from https://github.com/FormidableLabs/victory/blob/master/src/index.js

var Victory = {
  "Area": function() {},
  "Bar": function() {},
  "Candle": function() {},
  "ClipPath": function() {},
  "Collection": function() {},
  "Curve": function() {},
  "Data": function() {},
  "DefaultTransitions": function() {},
  "Domain": function() {},
  "ErrorBar": function() {},
  "Events": function() {},
  "Flyout": function() {},
  "Helpers": function() {},
  "Line": function() {},
  "Log": function() {},
  "Point": function() {},
  "Portal": function() {},
  "PropTypes": function() {},
  "Scale": function() {},
  "Slice": function() {},
  "Style": function() {},
  "TextSize": function() {},
  "Transitions": function() {},
  "VictoryAnimation": function() {},
  "VictoryArea": function() {},
  "VictoryAxis": function() {},
  "VictoryBar": function() {},
  "VictoryCandlestick": function() {},
  "VictoryChart": function() {},
  "VictoryClipContainer": function() {},
  "VictoryContainer": function() {},
  "VictoryErrorBar": function() {},
  "VictoryGroup": function() {},
  "VictoryLabel": function() {},
  "VictoryLine": function() {},
  "VictoryPie": function() {},
  "VictoryPortal": function() {},
  "VictoryScatter": function() {},
  "VictorySharedEvents": function() {},
  "VictoryStack": function() {},
  "VictoryTheme": function() {},
  "VictoryTooltip": function() {},
  "VictoryTransition": function() {},
  "VictoryVoronoi": function() {},
  "VictoryVoronoiTooltip": function() {},
  "VictoryZoom": function() {},
  "Voronoi": function() {},
  "addEvents": function() {}
}

==> victory-0.24.2-0.jar: cljsjs/common/victory.ext.js <==
// List manually adapted from https://github.com/FormidableLabs/victory/blob/master/src/index.js

var Victory = {
  "Area": function() {},
  "Bar": function() {},
  "BrushHelpers": function() {},
  "Candle": function() {},
  "ClipPath": function() {},
  "Collection": function() {},
  "Curve": function() {},
  "Data": function() {},
  "DefaultTransitions": function() {},
  "Domain": function() {},
  "ErrorBar": function() {},
  "Events": function() {},
  "Flyout": function() {},
  "Helpers": function() {},
  "Line": function() {},
  "Log": function() {},
  "Point": function() {},
  "Portal": function() {},
  "PropTypes": function() {},
  "Scale": function() {},
  "SelectionHelpers": function() {},
  "Slice": function() {},
  "Style": function() {},
  "TextSize": function() {},
  "Transitions": function() {},
  "VictoryAnimation": function() {},
  "VictoryArea": function() {},
  "VictoryAxis": function() {},
  "VictoryBar": function() {},
  "VictoryBrushContainer": function() {},
  "VictoryCandlestick": function() {},
  "VictoryChart": function() {},
  "VictoryClipContainer": function() {},
  "VictoryContainer": function() {},
  "VictoryErrorBar": function() {},
  "VictoryGroup": function() {},
  "VictoryLabel": function() {},
  "VictoryLegend": function() {},
  "VictoryLine": function() {},
  "VictoryPie": function() {},
  "VictoryPortal": function() {},
  "VictoryScatter": function() {},
  "VictorySelectionContainer": function() {},
  "VictorySharedEvents": function() {},
  "VictoryStack": function() {},
  "VictoryTheme": function() {},
  "VictoryTooltip": function() {},
  "VictoryTransition": function() {},
  "VictoryVoronoi": function() {},
  "VictoryVoronoiTooltip": function() {},
  "VictoryZoom": function() {},
  "VictoryZoomContainer": function() {},
  "Voronoi": function() {},
  "ZoomHelpers": function() {},
  "addEvents": function() {}
}
